@@ -1,6 +1,10 @@
 from ..node import Node
 from .program_module import ProgramModule
-from gql import gql
+from ...gql import gql
+from typing import List, TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from .program_track_action_response import ProgramTrackActionResponse
 
 programTrackActionFragment = """
 fragment ProgramTrackAction on ProgramTrackAction {
@@ -15,7 +19,7 @@ fragment ProgramTrackAction on ProgramTrackAction {
 
 
 class ProgramTrackAction(Node):
-    def __init__(self, data, context=None):
+    def __init__(self, data, context):
         super().__init__(data, context=context)
 
     @property
@@ -66,11 +70,11 @@ class ProgramTrackAction(Node):
 
         return responses
 
-    async def poll_responses(self):
+    async def poll_responses(self) -> List["ProgramTrackActionResponse"]:
         return await self._context.client.poll_program_track_action_responses(
             {"programTrackActionId": {"eq": self.id}}
         )
 
-    async def wait_for_response(self):
+    async def wait_for_response(self) -> "ProgramTrackActionResponse":
         responses = await self.poll_responses()
         return responses[0]
