@@ -1,5 +1,4 @@
 from ..node import Node
-from gql import gql
 
 tagFragment = """
 fragment Tag on Tag {
@@ -12,7 +11,7 @@ fragment Tag on Tag {
 
 
 class Tag(Node):
-    def __init__(self, data, context=None):
+    def __init__(self, data, context):
         super().__init__(data, context=context)
 
     @property
