@@ -26,6 +26,25 @@ class BlocksActionBuilder(object):
     def add_note(self, text: str):
         return self.add_block({"type": "note", "text": text,})
 
+    def add_sensor_field(
+        self,
+        title: str,
+        required: bool = False,
+        id: str = None,
+        samplingFrequency: int = 100,
+        sensorTypes: List[str] = [],
+    ):
+        return self.add_block(
+            {
+                "type": "sensorField",
+                "title": title,
+                "required": required,
+                "id": id,
+                "samplingFrequency": samplingFrequency,
+                "sensorTypes": sensorTypes,
+            }
+        )
+
     def add_text_field(
         self, title: str, required: bool = False, id: str = None, suggestions: List[str] = None
     ):
